@@ -1,9 +1,10 @@
 # <@LICENSE>
-# Copyright 2004 Apache Software Foundation
-# 
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to you under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at:
 # 
 #     http://www.apache.org/licenses/LICENSE-2.0
 # 
@@ -94,20 +95,20 @@ use vars qw{
   @site_rules_path
 };
 
-$VERSION = "3.001004";      # update after release (same format as perl $])
+$VERSION = "3.001008";      # update after release (same format as perl $])
 #$IS_DEVEL_BUILD = 1;        # change for release versions
 
 @ISA = qw();
 
 # SUB_VERSION is now just <yyyy>-<mm>-<dd>
-$SUB_VERSION = (split(/\s+/,'$LastChangedDate: 2006-07-25 15:06:10 -0700 (Tue, 25 Jul 2006) $ updated by SVN'))[1];
+$SUB_VERSION = (split(/\s+/,'$LastChangedDate: 2007-02-13 10:18:58 -0800 (Tue, 13 Feb 2007) $ updated by SVN'))[1];
 
 # If you hacked up your SA, you should add a version_tag to your .cf files.
 # This variable should not be modified directly.
 @EXTRA_VERSION = qw();
 if (defined $IS_DEVEL_BUILD && $IS_DEVEL_BUILD) {
   push(@EXTRA_VERSION,
-       ('r' . qw{$LastChangedRevision: 425535 $ updated by SVN}[1]));
+       ('r' . qw{$LastChangedRevision: 507135 $ updated by SVN}[1]));
 }
 
 sub Version {
@@ -122,7 +123,7 @@ $HOME_URL = "http://spamassassin.apache.org/";
 # version installed.  Unless you can come up with a fix for this that
 # allows "make test" to work, don't change this.
 @default_rules_path = (
-  '__local_state_dir__/spamassassin/__version__',
+  '__local_state_dir__/__version__',
   '__def_rules_dir__',
   '__prefix__/share/spamassassin',
   '/usr/local/share/spamassassin',
@@ -149,7 +150,6 @@ $HOME_URL = "http://spamassassin.apache.org/";
   '/etc/mail/spamassassin/user_prefs.template',
   '/usr/local/share/spamassassin/user_prefs.template',
   '/usr/share/spamassassin/user_prefs.template',
-  './rules/user_prefs.template',
 );
 
 @default_userprefs_path = (
@@ -220,6 +220,12 @@ found in the SpamAssassin B<rules> directory.
 If set to 1, no tests that require internet access will be performed. (default:
 0)
 
+=item ignore_site_cf_files
+
+If set to 1, any rule files found in the C<site_rules_filename> directory will
+be ignored.  *.pre files (used for loading plugins) found in the
+C<site_rules_filename> directory will still be used. (default: 0)
+
 =item dont_copy_prefs
 
 If set to 1, the user preferences file will not be created if it doesn't
@@ -246,7 +252,37 @@ effective UID under UNIX).
 
 If none of C<rules_filename>, C<site_rules_filename>, C<userprefs_filename>, or
 C<config_text> is set, the C<Mail::SpamAssassin> module will search for the
-configuration files in the usual installed locations.
+configuration files in the usual installed locations using the below variable
+definitions which can be passed in.
+
+=over 4
+
+=item PREFIX
+
+Used as the root for certain directory paths such as:
+
+  '__prefix__/etc/mail/spamassassin'
+  '__prefix__/etc/spamassassin'
+
+Defaults to "/usr/local".
+
+=item DEF_RULES_DIR
+
+Location where the default rules are installed.  Defaults to
+"/usr/local/share/spamassassin".
+
+=item LOCAL_RULES_DIR
+
+Location where the local site rules are installed.  Defaults to
+"/etc/mail/spamassassin".
+
+=item LOCAL_STATE_DIR
+
+Location of the local state directory, mainly used for installing updates via
+C<sa-update>.  Defaults to "/var/db/spamassassin".
+
+=back
+
 
 =cut
 
@@ -271,8 +307,12 @@ sub new {
   dbg("generic: SpamAssassin version " . Version());
 
   # if the libs are installed in an alternate location, and the caller
-  # didn't set PREFIX, we should have an estimated guess ready ...
-  $self->{PREFIX} ||= '/usr/local';  # substituted at 'make' time
+  # didn't set PREFIX, we should have an estimated guess ready, values
+  # substituted at 'make' time
+  $self->{PREFIX}		||= '/usr/local';
+  $self->{DEF_RULES_DIR}	||= '/usr/local/share/spamassassin';
+  $self->{LOCAL_RULES_DIR}	||= '/etc/mail/spamassassin';
+  $self->{LOCAL_STATE_DIR}	||= '/var/db/spamassassin';
 
   $self->{conf} ||= new Mail::SpamAssassin::Conf ($self);
   $self->{plugins} = Mail::SpamAssassin::PluginHandler->new ($self);
@@ -1242,6 +1282,10 @@ sub lint_rules {
 
   $self->{dont_copy_prefs} = $olddcp;       # revert back to previous
 
+  # bug 5048: override settings to ensure a faster lint
+  $self->{'conf'}->{'use_auto_whitelist'} = 0;
+  $self->{'conf'}->{'bayes_auto_learn'} = 0;
+
   my $mail = $self->parse(\@testmsg, 1);
   my $status = Mail::SpamAssassin::PerMsgStatus->new($self, $mail,
                         { disable_auto_learning => 1 } );
@@ -1346,7 +1390,7 @@ sub init {
     }
 
     $fname = $siterules;
-    if ($fname) {
+    if ($fname && !$self->{ignore_site_cf_files}) {
       $self->{config_text} .= $self->read_cf ($fname, 'site rules dir');
     }
 
@@ -1806,6 +1850,7 @@ E<lt>http://wiki.apache.org/spamassassin/E<gt> for more information.
 Mail::SpamAssassin::Conf(3)
 Mail::SpamAssassin::PerMsgStatus(3)
 spamassassin(1)
+sa-update(1)
 
 =head1 BUGS
 
